| analytik_sensors | R Documentation |
A vector of indexes for extracting subsets of spectra from the
sensors.mspct object.
analytik_sensors
An object of class character of length 0.
UVX-25, UVX-31 and UVX-36 sensor for UV-C, UV-B and UV-A radiation, respectively. Detection system includes optical filters and a Si photodiode.
Manufacturer: Analytik Jena US LLC, Upland, CA, USA (former UVP) https://www.analytik-jena.com/ or https://www.uvp.com/.
Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.
Product manual: 'UVP UVX Radiometer: Instruction Guide' (figures 6, 7 and 8).
sensors.mspct
analytik_sensors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.