angular_response: Angular response

View source: R/angular-response..R

angular_responseR Documentation

Angular response

Description

Angular response of idealized entrance optics used in light measurements.

Usage

angular_response(
  elevation.angle = 90,
  geometry = "cosine",
  zenith.angle = 90 - elevation.angle,
  diameter = NULL
)

Arguments

elevation.angle, zenith.angle

numeric The elevation angle of a point light source such as the sun or its zenith angle [degrees].

geometry

character The type of entrance optics, one of "flat disk", "cosine", "dome", "hemisphere", "ball", or "sphere".

diameter

numeric The diameter of the entrance optics. If NULL, the default, a relative value is returned.

Details

The maximum projected area (A_\mathrm{max}) is always computed for a circle of diameter d as A_\mathrm{max} = \pi \times d^2 / 4 when computing actual projected areas, or set to A_\mathrm{max} = 1 for computation of relative values.

The cosine response for a flat disk is computed as

A_\mathrm{p} = A_\mathrm{max} \times \cos(z)

The hemispherical response for a dome is computed as

A_\mathrm{p} = A_\mathrm{max} \times 0.5 \times (1 + \cos(z))

The spherical response for a "ball" is computed as

A_\mathrm{p} = A_\mathrm{max} \times 1

See Also

all_diffusers and diffusers.lst for data for real sensors and entrance optics.

Examples

angular_response(45)
angular_response(45, "cosine")
angular_response(45, "dome")
angular_response(45, "sphere")
angular_response(c(0, 30, 60, 90))
angular_response(-c(0, 30, 60, 90))
angular_response(c(0, 30, 60, 90), "dome")
angular_response(c(0, 30, 60, 90), "sphere")


photobiologySensors documentation built on March 14, 2026, 1:06 a.m.