| deltat_sensors | R Documentation |
A vector of indexes for extracting subsets of spectra from the
sensors.mspct object.
deltat_sensors
An object of class character of length 1.
From figure in manufacturer's manual. The Delta-T BF5 in a broadband diffuse and total irradiance sensor calibrated for photosynthetically active radiation (PAR). It is based on seven Si photodiodes as a shading dome with a custom pattern of openings.
Manufacturer: Delta-T Devices Ltd, CAMBRIDGE CB25 0EJ, UK https://delta-t.co.uk/
Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.
Manufacturer's User Manual Version: 1.0 dated Nov 2010
sensors.mspct
deltat_sensors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.