| diffusers.lst | R Documentation |
A collection of angular response data for selected broadband sensors used for measuring ultraviolet and visible radiation and of cosine diffusers used with spectrometers.
diffusers.lst
A list object containing data.frame
objects as named members.
Each member spectrum contains three variables:
angle.deg (degrees)
response (/1)
response.over.cosine (/1)
Each data frame in the list contains three variables, angle.deg (degrees) at either regular or irregular intervals, response relative to the maximum (as a fraction of one) and response relative to a perfect cosine response (as a fraction of one). Data are either from manufacturer specifications or independent measurements reported in the scientific literature.
Values are only good as reference, as individual sensors and diffusers deviate to a smaller or larger extent from typical or mean responses for their type. Variability is also reflected in some cases as an asymmetry in opposite angles away from the vertical.
Vectors of names in all_diffusers and function
angular_response().
names(diffusers.lst)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.