electronic_components: Types of sensors

electronic_componentsR Documentation

Types of sensors

Description

A vector of indexes for extracting subsets of spectra from the sensors.mspct object.

Usage

electronic_components

Format

An object of class character of length 15.

Details

The sensors pointed at by this vector are those sold as electronic components and used to construct sensors that can be deployed when interfaced to other electronic components, possibly combined with optical filters and entrance optics and protected inside a case or enclosure.

See Also

sensors.mspct

Examples

electronic_components


photobiologySensors documentation built on March 14, 2026, 1:06 a.m.