image_sensors.mspct: Spectral response of image sensors

image_sensors.mspctR Documentation

Spectral response of image sensors

Description

A collection of response spectra for various image sensors and digital cameras responsive to ultraviolet, visible, NIR and/or SWIR radiation. Each spectrum in the collection contains two variables, wavelengths (nm) at irregular intervals and spectral responsiveness (in photon units = quantum efficiency). Spectral data are normalized to one at the wavelength of maximum quantum efficiency only when this is how the original source published the data.

Usage

image_sensors.mspct

Format

A response_mspct object containing response_spct objects as named members.

Spectral objects for monochrome image sensors contain two numeric variables, with quantum efficiency in some cases in relative energy units:

  • w.length (nm)

  • s.q.response (r.u.)

Spectral objects for colour image sensors contain the spectra in long form with two numeric variables, and in addition a factor with channel ids:

  • w.length (nm)

  • s.q.response (r.u.)

  • channel (factor with names as levels)

The spectral objects contain, in addition to the spectral data, metadata stored in R attributes sensor.properties, what.measured, how.measured, and comment.

See Also

response_spct and response_mspct

Examples

names(image_sensors.mspct)


photobiologySensors documentation built on March 14, 2026, 1:06 a.m.