| specmeters_sensors | R Documentation |
A vector of indexes for extracting subsets of spectra from the
sensors.mspct object.
specmeters_sensors
An object of class character of length 1.
Specmeters 3415F PAR quantum sensor.
Manufacturer: Spectrum Technologies, Inc., Aurora, IL, USA. https://www.specmeters.com/
Digitized with 'DigitizeIt' or 'engauge' from manufacturers publications. This are approximate data, both because of the digitizing process, and because they are either typical values or for a specific sensor unit. Individual sensor units are expected to differ to some degree in spectral response. In the case of multichannel sensors, the spectra for all channels are plotted in the same figure in the data sheets and in out-of-band regions the lines overlap making accurate extraction of values difficult. Variation from unit to unit affects both response and center/peak wavelengths.
Quantum Light Meters PRODUCT MANUAL (R 06/14). https://www.specmeters.com/
sensors.mspct
specmeters_sensors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.