| electronic_components | R Documentation |
A vector of indexes for extracting subsets of spectra from the
sensors.mspct object.
electronic_components
An object of class character of length 15.
The sensors pointed at by this vector are those sold as electronic components and used to construct sensors that can be deployed when interfaced to other electronic components, possibly combined with optical filters and entrance optics and protected inside a case or enclosure.
sensors.mspct
electronic_components
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.