| uv_sensors | R Documentation |
A vector of indexes for extracting subsets of spectra from the
sensors.mspct object.
uv_sensors
uvc_sensors
uvb_sensors
erythemal_sensors
uva_sensors
par_sensors
epar_sensors
vis_sensors
photometric_sensors
shortwave_sensors
pyranometer_sensors
red_sensors
far_red_sensors
blue_sensors
green_sensors
multichannel_sensors
An object of class character of length 27.
An object of class character of length 2.
An object of class character of length 6.
An object of class character of length 10.
An object of class character of length 8.
An object of class character of length 9.
An object of class character of length 1.
An object of class character of length 3.
An object of class character of length 3.
An object of class character of length 4.
An object of class character of length 4.
An object of class character of length 2.
An object of class character of length 2.
An object of class character of length 1.
An object of class character of length 1.
An object of class character of length 11.
The sensors pointed at by each of these vectors are sensitive to light of a certain colour within visible radiation (VIS) or to different bands of ultraviolet (UV) or infrared (IR) radiation.
sensors.mspct
uv_sensors # ultraviolet
uvc_sensors # ultraviolet-C
uvb_sensors # ultraviolet-B
uva_sensors # ultraviolet-A
epar_sensors # extended photosynthetically active radiation
par_sensors # photosynthetically active radiation
vis_sensors # "visual" light sensors
shortwave_sensors
red_sensors
far_red_sensors
blue_sensors
multichannel_sensors
# select PAR sensors
sensors.mspct[par_sensors]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.